@@ -37,8 +37,8 @@
 #ifndef UGREP_HPP
 #define UGREP_HPP
 
-// ugrep version
-#define UGREP_VERSION "5.1.1"
+// DO NOT ALTER THIS LINE: updated by makemake.sh and we need it physically here for MSVC++ build from source
+#define UGREP_VERSION "5.1.3"
 
 // disable mmap because mmap is almost always slower than the file reading speed improvements since 3.0.0
 #define WITH_NO_MMAP
@@ -225,6 +225,10 @@ inline int fopenw_s(FILE **file, const char *filename, const char *mode)
 # include <sys/param.h>
 #endif
 
+#ifdef HAVE_SYS_MOUNT_H
+# include <sys/mount.h>
+#endif
+
 #ifdef HAVE_SYS_CPUSET_H
 # include <sys/cpuset.h>
 #endif
@@ -401,7 +405,7 @@ inline const char *utf8skipn(const char *s, size_t n, size_t k)
 # define DEFAULT_MAX_MMAP_SIZE MAX_MMAP_SIZE
 #endif
 
-// pretty is disabled by default for ugrep (always enabled by ug), unless enabled with WITH_PRETTY
+// pretty is disabled by default for ugrep (but always enabled by ug), unless enabled with WITH_PRETTY
 #ifdef WITH_PRETTY
 # define DEFAULT_PRETTY Static::AUTO
 #else
